function dclde2013_demo()
% dclde2013_demo()
% Shows how to write files for DCLDE 2013.
% Note:  time and frequency values are made up and not appropriate for
% any specific species.

% Detections may have a variety of formats, they might be:
%  start and end times
%  time-frequency bounding boxes
%  time-frequency contours

% Needed imports to access Java classes
% These will fail in javaclasspath is not set properly,
% see docs.
import tonals.TonalHeader;
import tonals.TonalBinaryOutputStream;

% start and end times
% Assume times is an Nx2 matrix with start and end times.
% Here we keep it simple and use a 2x2.
times = [
    17.2 19  % all made up
    25 28];
Hz = [0 0];  % Interface requires Hz even though it will not be saved
scores = [50, 2];  % arbitrary scores

mask = bitor(TonalHeader.TIME, TonalHeader.SCORE);  % what we'll save
detversion = 1;  % detector version
ostream = tonals.TonalBinaryOutputStream('timeonly.det', detversion, ...
    'my super detector/classifier', mask);
for idx = 1:size(times, 1)
    ostream.write_s(times(idx,:), Hz, scores(idx));
end
ostream.close();

% bounding boxes and time x frequency contours are the same
% the only difference is the lengths of the vectors.  We'll show
% bounding boxes here

bbox(1).time = [17.2 19];   % these would be generated by your detector
bbox(1).freq = [40 60];
bbox(1).score = 72;
bbox(2).time = [25 28];
bbox(2).freq = [50 60];
bbox(2).score = 49;

mask = bitor(TonalHeader.DEFAULT, TonalHeader.SCORE);  % time, freq, score
detversion = 1;  % detector version
ostream = tonals.TonalBinaryOutputStream('timefreq.det', detversion, ...
    'my 2nd generation detector/classifier', mask);
for idx = 1:length(bbox)
    ostream.write_s(bbox(idx).time, bbox(idx).freq, bbox(idx).score);
end
ostream.close();

% Note that if you generate instances of Silbido's tonal class, those can
% be used in place of the time/freq paramemters and is currently the
% only way to store phase and SNR.  LinkedLists of Silbido's tonal class
% can also be passed to dtTonalsSave(), see tonal_test for an example
% of this.


    